@@ -34,6 +34,7 @@
 
 #include <glibtop/close.h>
 
+#include <locale.h>
 #include <assert.h>
 
 extern GnomePropertyDescriptor GlobalProperty_Descriptor;
@@ -45,6 +46,9 @@ GnomeClient *client;
 static void about_cb (GtkWidget *widget, void *data);
 static void start_stop_cb (GtkWidget *widget);
 
+       void gtop_show_mtbar   (GtkWidget *, gpointer);
+static void gtop_toggle_mtbar (GtkWidget *, gpointer);
+
 static int
 delete_event_handler (GtkWidget *widget)
 {
@@ -111,11 +115,22 @@ GnomeUIInfo helpMenu [] = {
 	GNOMEUIINFO_HELP ("libgtop"),
 	GNOMEUIINFO_SEPARATOR,
 #endif
+	GNOMEUIINFO_HELP ("gtop"),
 	GNOMEUIINFO_MENU_ABOUT_ITEM (about_cb, NULL),
 	GNOMEUIINFO_END
 };
 
 GnomeUIInfo settingsMenu [] = {
+	{ GNOME_APP_UI_TOGGLEITEM,
+	  N_("Show _menubar"), N_("Show menubar"),
+	  gtop_toggle_mtbar, (gpointer) FALSE, NULL,
+	  GNOME_APP_PIXMAP_DATA, GNOME_APP_PIXMAP_NONE,
+	  'm', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_TOGGLEITEM,
+	  N_("Show _toolbar"), N_("Show toolbar"),
+	  gtop_toggle_mtbar, (gpointer) TRUE, NULL,
+	  GNOME_APP_PIXMAP_DATA, GNOME_APP_PIXMAP_NONE,
+	  't', GDK_CONTROL_MASK, NULL },
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM (gtop_show_properties, NULL),
 	GNOMEUIINFO_END
@@ -146,6 +161,43 @@ gtop_quit (void)
         gtk_main_quit ();
 }
 
+void
+gtop_show_mtbar (GtkWidget *w, gpointer gp)
+{
+	GnomeUIInfo *mb = gnome_mdi_get_menubar_info (gnome_mdi_get_active_window (mdi));
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
+					(((GnomeUIInfo *)mb [1].moreinfo) [(gp) ? 1 : 0].widget), 1);
+}
+
+static void
+gtop_toggle_mtbar (GtkWidget *w, gpointer gp)
+{
+	GList     *c = mdi->windows;
+	GnomeApp  *app;
+	GtkWidget *bw;
+	gint       which = (gint) gtk_object_get_data
+                (GTK_OBJECT (w), GNOMEUIINFO_KEY_UIDATA);
+
+	while (c) {
+		app = (GnomeApp *) c->data;
+		bw = GTK_WIDGET (gnome_app_get_dock_item_by_name
+			(app, (which) ? GNOME_APP_TOOLBAR_NAME : GNOME_APP_MENUBAR_NAME));
+
+		if (GTK_CHECK_MENU_ITEM (w)->active) {
+			gtk_widget_show (bw);
+		} else {
+			gtk_widget_hide (bw);
+			gtk_widget_queue_resize (GTK_WIDGET (app));
+		}
+		c = c->next;
+	}
+
+	if (which)
+		gtop_properties.global.show_toolbar = GTK_CHECK_MENU_ITEM (w)->active;
+	else
+		gtop_properties.global.show_menubar = GTK_CHECK_MENU_ITEM (w)->active;
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -153,6 +205,7 @@ main (int argc, char *argv[])
 	poptContext ctx;
 	const char **args;
 
+	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 
@@ -230,6 +283,17 @@ main (int argc, char *argv[])
         gtk_main ();
 
 	glibtop_close ();
+
+	if (gtop_properties.global.save_session) {
+		gnome_config_set_int
+			("gtop/global/show_menubar",
+			 gtop_properties.global.show_menubar);
+
+		gnome_config_set_int
+			("gtop/global/show_toolbar",
+			 gtop_properties.global.show_toolbar);
+		gnome_config_sync ();
+	}
         
         return 0;
 }
